@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2008 - 2010 Lukas Hetzenecker <LuHe@gmx.at>
+# Copyright (c) 2011 - 2012 Michal Čihař <michal@cihar.com>
 
 import sys
 sys.path.append('e:\python\libs')
@@ -37,7 +38,7 @@ import socket as pysocket
 import cPickle
 
 
-VERSION = 0.5
+VERSION = '0.6.0'
 PORT = 18
 
 # For hash functions
@@ -55,6 +56,7 @@ class Mobile(object):
         self.port = PORT
 
         self.loadConfig()
+        self.initUi()
 
         self.inbox = inbox.Inbox(inbox.EInbox)
         self.sent = inbox.Inbox(inbox.ESent)
@@ -66,7 +68,6 @@ class Mobile(object):
         self.inbox.bind(self.newMessage)
         #telephone.call_state(self.handleCall)
 
-        self.initUi()
         self.startService()
 
     def getCurrentDir(self):
@@ -89,7 +90,7 @@ class Mobile(object):
         return os.path.join(self.getCurrentDir(), name)
 
     def getConfigFilename(self):
-        return self.getFilename('s60.cfg')
+        return self.getFilename('gammu-s60.cfg')
 
     def getScreenshotFilename(self):
         return self.getFilename('screenshot.png')
@@ -119,7 +120,7 @@ class Mobile(object):
             pass
 
     def initUi(self):
-        app.title = u"Series 60 - Remote"
+        app.title = u"Gammu S60 Remote"
 
         if self.useCanvas:
             self.canvas = Canvas(redraw_callback=self.statusUpdate)
@@ -252,9 +253,11 @@ class Mobile(object):
     def wait(self):
         while(True):
             data = self.fis.readline()
+            parts = data.split(NUM_END_HEADER)
 
-            header = int(data.split(NUM_END_HEADER)[0])
-            message = unicode(data.split(NUM_END_HEADER)[1],  "utf8")
+            header = int(parts[0])
+            message = unicode(parts[1], "utf8")
+            message_parts = message.split(NUM_SEPERATOR)
 
             if (header != NUM_PARTIAL_MESSAGE and self.__partialMessage):
                 message = self.__partialMessage + message
@@ -267,7 +270,7 @@ class Mobile(object):
                     self.send(NUM_HELLO_REPLY)
 
             elif (header == NUM_SYSINFO_REQUEST):
-                full = bool(int(message.split(NUM_SEPERATOR)[0]))
+                full = bool(int(message_parts[0]))
                 self.sendSysinfo(full)
 
             elif (header == NUM_LOCATION_REQUEST):
@@ -275,7 +278,7 @@ class Mobile(object):
 
             elif (header == NUM_DIAL):
                 try:
-                    telephone.dial(message.split(NUM_SEPERATOR)[0])
+                    telephone.dial(message_parts[0])
                 except:
                     pass
 
@@ -295,7 +298,7 @@ class Mobile(object):
                 self.send(NUM_CONTACTS_REPLY_COUNT, len(self.contactDb))
 
             elif (header == NUM_CONTACTS_REQUEST_CONTACT):
-                key = int(message.split(NUM_SEPERATOR)[0])
+                key = int(message_parts[0])
                 try:
                     contact = self.contactDb[key]
                     self.sendContact(contact)
@@ -316,17 +319,17 @@ class Mobile(object):
                     del self.contactDb[id]
 
             elif (header == NUM_CONTACTS_CHANGE_ADDFIELD):
-                id = int(message.split(NUM_SEPERATOR)[0])
-                type = unicode(message.split(NUM_SEPERATOR)[1])
-                location = unicode(message.split(NUM_SEPERATOR)[2])
-                value = unicode(message.split(NUM_SEPERATOR)[3])
+                id = int(message_parts[0])
+                type = unicode(message_parts[1])
+                location = unicode(message_parts[2])
+                value = unicode(message_parts[3])
                 self.modifyContact("add",  id,  type,  location,  value)
 
             elif (header == NUM_CONTACTS_CHANGE_REMOVEFIELD):
-                id = int(message.split(NUM_SEPERATOR)[0])
-                type = unicode(message.split(NUM_SEPERATOR)[1])
-                location = unicode(message.split(NUM_SEPERATOR)[2])
-                value = unicode(message.split(NUM_SEPERATOR)[3])
+                id = int(message_parts[0])
+                type = unicode(message_parts[1])
+                location = unicode(message_parts[2])
+                value = unicode(message_parts[3])
                 self.modifyContact("remove",  id,  type,  location,  value)
 
             elif (header == NUM_CALENDAR_REQUEST_COUNT):
@@ -339,7 +342,7 @@ class Mobile(object):
             #    self.sendCalendarHashSingle()
 
             elif (header == NUM_CALENDAR_REQUEST_ENTRY):
-                key = int(message.split(NUM_SEPERATOR)[0])
+                key = int(message_parts[0])
                 try:
                     entry = self.calendarDb[key]
                     self.sendCalendarEntry(entry)
@@ -358,48 +361,46 @@ class Mobile(object):
                     pass
 
             elif (header == NUM_CALENDAR_ENTRY_CHANGE or header == NUM_CALENDAR_ENTRY_ADD):
-                ms = message.split(NUM_SEPERATOR)
-
                 if (header == NUM_CALENDAR_ENTRY_CHANGE):
-                    id = int(ms[0])
+                    id = int(message_parts[0])
                 elif (header == NUM_CALENDAR_ENTRY_ADD):
-                    type = str(ms[0])
+                    type = str(message_parts[0])
 
-                content = unicode(ms[1])
-                location = unicode(ms[2])
-                #start = float(ms[3]) if ms[3] else 0
-                if ms[3]:
-                    start = float(ms[3])
+                content = unicode(message_parts[1])
+                location = unicode(message_parts[2])
+                #start = float(message_parts[3]) if message_parts[3] else 0
+                if message_parts[3]:
+                    start = float(message_parts[3])
                 else:
                     start = 0.0
-                #end = float(ms[4]) if ms[4] else None
-                if ms[4]:
-                    end = float(ms[4])
+                #end = float(message_parts[4]) if message_parts[4] else None
+                if message_parts[4]:
+                    end = float(message_parts[4])
                 else:
                     end = None
-                replication = str(ms[5])
-                #alarm = float(ms[6]) if ms[6] else None
-                if ms[6]:
-                    alarm = float(ms[6])
+                replication = str(message_parts[5])
+                #alarm = float(message_parts[6]) if message_parts[6] else None
+                if message_parts[6]:
+                    alarm = float(message_parts[6])
                 else:
                     alarm = None
-                priority = int(ms[7])
-                repeat_type = str(ms[8])
-                repeat_days = str(ms[9])
-                repeat_exceptions = str(ms[10])
-                #repeat_start = float(ms[11]) if ms[11] else 0
-                if ms[11]:
-                    repeat_start = float(ms[11])
+                priority = int(message_parts[7])
+                repeat_type = str(message_parts[8])
+                repeat_days = str(message_parts[9])
+                repeat_exceptions = str(message_parts[10])
+                #repeat_start = float(message_parts[11]) if message_parts[11] else 0
+                if message_parts[11]:
+                    repeat_start = float(message_parts[11])
                 else:
                     repeat_start = 0.0
-                #repeat_end = float(ms[12]) if ms[12] else None
-                if ms[12]:
-                    repeat_end = float(ms[12])
+                #repeat_end = float(message_parts[12]) if message_parts[12] else None
+                if message_parts[12]:
+                    repeat_end = float(message_parts[12])
                 else:
                     repeat_end = None
-                #repeat_interval = int(ms[13]) if ms[13] else 1
-                if ms[13]:
-                    repeat_interval = int(ms[13])
+                #repeat_interval = int(message_parts[13]) if message_parts[13] else 1
+                if message_parts[13]:
+                    repeat_interval = int(message_parts[13])
                 else:
                     repeat_interval = 1
 
@@ -411,11 +412,11 @@ class Mobile(object):
                                         repeat_days,  repeat_exceptions,  repeat_start,  repeat_end,  repeat_interval)
 
             elif (header == NUM_MESSAGE_REQUEST):
-                lastId = int(message.split(NUM_SEPERATOR)[0])
+                lastId = int(message_parts[0])
                 self.sendAllMessages(lastId)
 
             elif (header == NUM_MESSAGE_REQUEST_ONE):
-                lastId = int(message.split(NUM_SEPERATOR)[0])
+                lastId = int(message_parts[0])
                 self.sendOneMessage(lastId)
 
             elif (header == NUM_MESSAGE_REQUEST_UNREAD):
@@ -428,19 +429,19 @@ class Mobile(object):
                 self.sendMessagesCount()
 
             elif (header == NUM_MESSAGE_SEND_REQUEST):
-                name = unicode(message.split(NUM_SEPERATOR)[0])
-                phone = unicode(message.split(NUM_SEPERATOR)[1])
-                enc = str(message.split(NUM_SEPERATOR)[2])
-                msg = unicode(message.split(NUM_SEPERATOR)[3])
+                name = unicode(message_parts[0])
+                phone = unicode(message_parts[1])
+                enc = str(message_parts[2])
+                msg = unicode(message_parts[3]).decode('string_escape')
                 self.sendMessage(name, phone, enc,  msg)
 
             elif (header == NUM_SET_READ):
-                id = int(message.split(NUM_SEPERATOR)[0])
-                state = bool(message.split(NUM_SEPERATOR)[1])
+                id = int(message_parts[0])
+                state = bool(message_parts[1])
                 self.setRead(id, state)
 
             elif (header == NUM_MESSAGE_DELETE):
-                id = int(message.split(NUM_SEPERATOR)[0])
+                id = int(message_parts[0])
                 self.messageDelete(id)
 
             elif (header == NUM_SCREENSHOT):
@@ -1087,7 +1088,7 @@ class Mobile(object):
             self.send(NUM_MESSAGE_SEND_REPLY_STATUS,  "Moved to outbox.")
         elif status == messaging.EScheduledForSend:
             self.send(NUM_MESSAGE_SEND_REPLY_STATUS,  "Scheduled for send.")
-        if status == messaging.ESent:
+        elif status == messaging.ESent:
             self.send(NUM_MESSAGE_SEND_REPLY_STATUS,  "Message sent.")
         elif status == messaging.EDeleted:
             self.send(NUM_MESSAGE_SEND_REPLY_OK,  "The SMS message has been deleted from device's outbox queue.")
@@ -1099,6 +1100,8 @@ class Mobile(object):
             self.send(NUM_MESSAGE_SEND_REPLY_FAILURE,  "No service centre.")
         elif status == messaging.EFatalServerError:
             self.send(NUM_MESSAGE_SEND_REPLY_FAILURE,  "SMS send failed! If the device is in offline-mode or with no network connection the message is added to the device's outgoing message queue.")
+        else:
+            self.send(NUM_MESSAGE_SEND_REPLY_STATUS, "Unknown status: %s" % status)
 
     def newMessage(self, sms):
         if not self.connected:
@@ -1167,7 +1170,7 @@ class Mobile(object):
             self.startService()
 
     def aboutHandler(self):
-        query(u'Series60 - remote\nVersion %s\nModified for Gammu\nhttp://wammu.eu/' % (VERSION) , 'query')
+        query(u'Gammu S60 Remote\nVersion %s\nhttp://wammu.eu/' % (VERSION) , 'query')
 
     def toggleHandler(self):
         e32.start_exe(u'BtToggleApp.exe','')
@@ -1196,7 +1199,7 @@ except Exception, e:
     err_msg = u"This programs was unexpectedly closed due to the following error: "
     err_msg += unicode(repr(e)) + new_line
     err_msg += u"Please, copy and paste the text presented here and "
-    err_msg += u"send it to series60-remote-devel@lists.sourceforge.net. "
+    err_msg += u"send it to gammu-users@lists.sourceforge.net. "
     err_msg += u"Thanks in advance and sorry for this inconvenience." + new_line*2
     err_msg += u"Call stack:" + new_line + call_stack
 
