@@ -1589,89 +1589,6 @@ void GSM_OSErrorInfo(GSM_StateMachine *s, const char *description)
 #endif
 }
 
-#ifdef GSM_ENABLE_BACKUP
-
-void GSM_GetPhoneFeaturesForBackup(GSM_StateMachine *s, GSM_Backup_Info *info)
-{
-	GSM_Error 		error;
-	GSM_MemoryStatus	MemStatus;
-	GSM_ToDoStatus		ToDoStatus;
-	GSM_CalendarEntry       Note;
-	GSM_WAPBookmark		Bookmark;
-	GSM_MultiWAPSettings	WAPSettings;
- 	GSM_FMStation		FMStation;
- 	GSM_GPRSAccessPoint	GPRSPoint;
-
-	if (info->PhonePhonebook) {
-		MemStatus.MemoryType = MEM_ME;
-                error=s->Phone.Functions->GetMemoryStatus(s, &MemStatus);
-		if (error==ERR_NONE && MemStatus.MemoryUsed != 0) {
-		} else {
-			info->PhonePhonebook = FALSE;
-		}
-	}
-	if (info->SIMPhonebook) {
-		MemStatus.MemoryType = MEM_SM;
-                error=s->Phone.Functions->GetMemoryStatus(s, &MemStatus);
-		if (error==ERR_NONE && MemStatus.MemoryUsed != 0) {
-		} else {
-			info->SIMPhonebook = FALSE;
-		}
-	}
-	if (info->Calendar) {
-		error=s->Phone.Functions->GetNextCalendar(s,&Note,TRUE);
-		if (error!=ERR_NONE) info->Calendar = FALSE;
-	}
-	if (info->ToDo) {
-		error=s->Phone.Functions->GetToDoStatus(s,&ToDoStatus);
-		if (error == ERR_NONE && ToDoStatus.Used != 0) {
-		} else {
-			info->ToDo = FALSE;
-		}
-	}
-	if (info->WAPBookmark) {
-		Bookmark.Location = 1;
-		error=s->Phone.Functions->GetWAPBookmark(s,&Bookmark);
-		if (error == ERR_NONE) {
-		} else {
-			info->WAPBookmark = FALSE;
-		}
-	}
-	if (info->WAPSettings) {
-		WAPSettings.Location = 1;
-		error=s->Phone.Functions->GetWAPSettings(s,&WAPSettings);
-		if (error == ERR_NONE) {
-		} else {
-			info->WAPSettings = FALSE;
-		}
-	}
-	if (info->MMSSettings) {
-		WAPSettings.Location = 1;
-		error=s->Phone.Functions->GetMMSSettings(s,&WAPSettings);
-		if (error == ERR_NONE) {
-		} else {
-			info->WAPSettings = FALSE;
-		}
-	}
-	if (info->FMStation) {
- 		FMStation.Location = 1;
- 		error = s->Phone.Functions->GetFMStation(s,&FMStation);
- 	        if (error == ERR_NONE || error == ERR_EMPTY) {
-		} else {
-			info->FMStation = FALSE;
-		}
-	}
-	if (info->GPRSPoint) {
- 		GPRSPoint.Location = 1;
- 		error = s->Phone.Functions->GetGPRSAccessPoint(s,&GPRSPoint);
- 	        if (error == ERR_NONE || error == ERR_EMPTY) {
-		} else {
-			info->GPRSPoint = FALSE;
-		}
-	}
-}
-#endif
-
 void GSM_SetIncomingCallCallback(GSM_StateMachine *s, IncomingCallCallback callback, void *user_data)
 {
 	s->User.IncomingCall = callback;
