@@ -457,6 +457,8 @@ GSM_Error ATGEN_DecodePDUMessage(GSM_StateMachine *s, const char *PDU, const int
 	/* Special dummy message used by Siemens MC35i to fill up memory when using MT storage */
 	if (strcmp(PDU, "00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF") == 0) {
 		return ERR_CORRUPTED;
+	} else if (strcmp(PDU, "00") == 0) {
+		return ERR_EMPTY;
 	}
 
 	/* Allocate memory for binary data */
@@ -511,6 +513,9 @@ GSM_Error ATGEN_DecodePDUMessage(GSM_StateMachine *s, const char *PDU, const int
 
 		if (buffer[parse_len] == 0xff) {
 			smprintf(s, "Assuming broken phone which pads SMS data with FF\n");
+		} else if (buffer[parse_len] == 0x89) {
+			/* Not sure what the data here means, see tests/at-sms/39.dump */
+			smprintf(s, "Assuming we can ignore anything starting with 0x89\n");
 		} else {
 			free(buffer);
 			return ERR_UNKNOWN;
@@ -521,6 +526,10 @@ GSM_Error ATGEN_DecodePDUMessage(GSM_StateMachine *s, const char *PDU, const int
 	/* Set folder */
 	switch (sms->PDU) {
 		case SMS_Deliver:
+			/* Fix possibly wrong state */
+			if (sms->State == SMS_Sent) {
+				sms->State = SMS_Read;
+			}
 			/* @bug Broken when MEM_SM is not available */
 			if (Priv->SMSMemory == MEM_SM) {
 				sms->Folder = 1; /*INBOX SIM*/
@@ -608,6 +617,10 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message *msg, GSM_StateMachine *
 				/* Some phones like ES75 lack state information, which we ignore anywa */
 				error = ATGEN_ParseReply(s, buffer, "+CMGR: @i", &state);
 			}
+			if (error == ERR_UNKNOWNRESPONSE) {
+				/* Some phones like QUALCOMM lack state information */
+				error = ATGEN_ParseReply(s, buffer, "+CMGR: ,,@i", &state);
+			}
 			if (error != ERR_NONE) {
 				return error;
 			}
@@ -1212,9 +1225,10 @@ GSM_Error ATGEN_GetSMSList(GSM_StateMachine *s, gboolean first)
 	if (error == ERR_NONE && Priv->SMSCache == NULL) {
 		Priv->SMSCache = (GSM_AT_SMS_Cache *)realloc(Priv->SMSCache, sizeof(GSM_AT_SMS_Cache));
 	}
-	if (used != Priv->SMSCount && error == ERR_NONE) {
+	if (used != Priv->SMSCount && (error == ERR_NONE || error == ERR_EMPTY)) {
 		smprintf(s, "WARNING: Used messages according to CPMS %d, but CMGL returned %d. Expect problems!\n", used, Priv->SMSCount);
 		smprintf(s, "HINT: Your might want to use F_USE_SMSTEXTMODE flag\n");
+		return ERR_NONE;
 	}
 	return error;
 }
@@ -1245,6 +1259,7 @@ GSM_Error ATGEN_GetNextSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, gboole
 	if (start) {
 		/* Start from beginning */
 		sms->SMS[0].Location = 0;
+		Priv->LastSMSRead = 0;
 
 		/* Get list of messages */
 		error = ATGEN_GetSMSList(s, TRUE);
@@ -2528,6 +2543,8 @@ GSM_Error ATGEN_ReplyGetCNMIMode(GSM_Protocol_Message *msg, GSM_StateMachine *s)
 		Priv->CNMIMode = 3; /* 3 = send messages directly */
 	}
 	else {
+		free(range);
+		range = NULL;
 		return ERR_NONE; /* we don't want: 1 = ignore new messages, 0 = store messages and no indication */
 	}
 	free(range);
