@@ -12,10 +12,11 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Copyright (c) 2011 Michal Cihar <michal@cihar.com>
+ * Copyright (c) 2011 - 2012 Michal Cihar <michal@cihar.com>
  */
 
 
+#define _GNU_SOURCE
 #include "../../gsmstate.h"
 #include "../../protocol/s60/s60-ids.h"
 #include "../../gsmcomon.h"
@@ -27,9 +28,11 @@
 #include "../pfunc.h"
 #include <string.h>
 
+#include "../../../helper/string.h"
+
 #if defined(GSM_ENABLE_S60)
 
-GSM_Error S60_Install(GSM_StateMachine *s, const char *ExtraPath)
+GSM_Error S60_Install(GSM_StateMachine *s, const char *ExtraPath, gboolean Minimal)
 {
 	GSM_StateMachine *gsm;
 	GSM_Debug_Info *debug_info;
@@ -45,33 +48,41 @@ GSM_Error S60_Install(GSM_StateMachine *s, const char *ExtraPath)
 	AppletFile.Buffer 	= NULL;
 	AppletFile.Used 	= 0;
 
-	error = PHONE_FindDataFile(s, &AppletFile, ExtraPath, "series60-remote.sis");
+	error = PHONE_FindDataFile(s, &AppletFile, ExtraPath, "gammu-s60-remote.sis");
 	if (error != ERR_NONE) {
 		smprintf(s, "Failed to find applet, trying another filename!\n");
-		error = PHONE_FindDataFile(s, &AppletFile, ExtraPath, "series60-remote-sign.sis");
+		error = PHONE_FindDataFile(s, &AppletFile, ExtraPath, "gammu-s60-remote-sign.sis");
 		if (error != ERR_NONE) {
 			smprintf(s, "Failed to load applet data!\n");
 			return ERR_INSTALL_NOT_FOUND;
 		}
 	}
 
-	error = PHONE_FindDataFile(s, &PythonFile, ExtraPath, "Python_2.0.0.sis");
-	if (error == ERR_NONE) {
-		install_python = TRUE;
-	} else {
-		smprintf(s, "Could not find Python for S60 to install, skipping!\n");
+	if (Minimal) {
+
 		install_python = FALSE;
 		install_pips = FALSE;
-	}
 
-	if (install_python) {
-		error = PHONE_FindDataFile(s, &PIPSFile, ExtraPath, "pips.sis");
+	} else {
+
+		error = PHONE_FindDataFile(s, &PythonFile, ExtraPath, "Python_2.0.0.sis");
 		if (error == ERR_NONE) {
-			install_pips = TRUE;
+			install_python = TRUE;
 		} else {
-			smprintf(s, "Could not find PIPS to install, skipping!\n");
+			smprintf(s, "Could not find Python for S60 to install, skipping!\n");
+			install_python = FALSE;
 			install_pips = FALSE;
 		}
+
+		if (install_python) {
+			error = PHONE_FindDataFile(s, &PIPSFile, ExtraPath, "pips.sis");
+			if (error == ERR_NONE) {
+				install_pips = TRUE;
+			} else {
+				smprintf(s, "Could not find PIPS to install, skipping!\n");
+				install_pips = FALSE;
+			}
+		}
 	}
 
 	gsm = GSM_AllocStateMachine();
@@ -174,7 +185,7 @@ GSM_Error S60_Initialise(GSM_StateMachine *s)
 		return error;
 	}
 
-	if (Priv->MajorVersion != 1 || Priv->MinorVersion != 5) {
+	if (Priv->MajorVersion != 1 || Priv->MinorVersion != 6) {
 		smprintf(s, "Unsupported protocol version\n");
 		return ERR_NOTSUPPORTED;
 	}
@@ -279,7 +290,7 @@ static GSM_Error S60_Reply_SendSMS(GSM_Protocol_Message *msg, GSM_StateMachine *
 			if (s->User.SendSMSStatus != NULL) {
 				s->User.SendSMSStatus(s, 1, -1, s->User.SendSMSStatusUserData);
 			}
-			return ERR_UNKNOWN;
+			return ERR_BUSY;
 		case NUM_MESSAGE_SEND_REPLY_STATUS:
 			return ERR_NONE;
 		case NUM_MESSAGE_SEND_REPLY_OK:
@@ -308,7 +319,7 @@ static GSM_Error S60_Reply_Connect(GSM_Protocol_Message *msg, GSM_StateMachine *
 		return ERR_UNKNOWN;
 	}
 	Priv->MinorVersion = atoi(pos + 1);
-	smprintf(s, "Connected to series60-remote version %d.%d\n", Priv->MajorVersion, Priv->MinorVersion);
+	smprintf(s, "Connected to Gammu S60 Remote version %d.%d\n", Priv->MajorVersion, Priv->MinorVersion);
 
 	return ERR_NONE;
 }
@@ -416,7 +427,7 @@ static GSM_Error S60_Reply_GetInfo(GSM_Protocol_Message *msg, GSM_StateMachine *
 		strcpy(s->Phone.Data.IMEI, Priv->MessageParts[1]);
 	} else if (strcmp(Priv->MessageParts[0], "model") == 0) {
 		/* Parse manufacturer */
-		pos = strstr(Priv->MessageParts[1], "(C)");
+		pos = strcasestr(Priv->MessageParts[1], "(C)");
 		if (pos != NULL) {
 			strcpy(s->Phone.Data.Manufacturer, pos + 3);
 		}
@@ -1910,6 +1921,7 @@ GSM_Error S60_GetNextSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, gboolean
 GSM_Error S60_SendSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 {
 	char buffer[((GSM_MAX_SMS_LENGTH + 1) * 2) + ((GSM_MAX_SMS_NAME_LENGTH + 1) * 2) + ((GSM_MAX_NUMBER_LENGTH + 1) * 2)];
+	char textbuffer[((GSM_MAX_SMS_LENGTH + 1) * 2)];
 
 	if (sms->UDH.Type != UDH_NoUDH) {
 		return ERR_NOTSUPPORTED;
@@ -1933,7 +1945,8 @@ GSM_Error S60_SendSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 			break;
 	}
 	strcat(buffer, NUM_SEPERATOR_STR);
-	EncodeUTF8(buffer + strlen(buffer), sms->Text);
+	EncodeUTF8(textbuffer, sms->Text);
+	EncodeSpecialChars(buffer + strlen(buffer), textbuffer);
 	strcat(buffer, NUM_SEPERATOR_STR);
 
 	return GSM_WaitFor(s, buffer, strlen(buffer), NUM_MESSAGE_SEND_REQUEST, S60_TIMEOUT, ID_None);
