@@ -337,11 +337,11 @@ gboolean ReadVCALDate(char *Buffer, const char *Start, GSM_DateTime *Date, gbool
 	char fullstart[200];
 	unsigned char datestring[200];
 
-	if (!ReadVCALText(Buffer, Start, datestring, FALSE)) {
+	if (!ReadVCALText(Buffer, Start, datestring, FALSE, NULL)) {
 		fullstart[0] = 0;
 		strcat(fullstart, Start);
 		strcat(fullstart, ";VALUE=DATE");
-		if (!ReadVCALText(Buffer, fullstart, datestring, FALSE)) {
+		if (!ReadVCALText(Buffer, fullstart, datestring, FALSE, NULL)) {
 			return FALSE;
 		}
 		*is_date_only = TRUE;
@@ -458,9 +458,14 @@ unsigned char *VCALGetTextPart(unsigned char *Buff, int *pos)
  * We separate matching text (Start) to tokens and then try to find all
  * tokens in Buffer. We also accept tokens like PREF, CHARSET or ENCODING.
  *
+ * Also it parses TYPE=* tokens, matching it to text types passed in Start
+ * parameter. For example Start "TEL;FAX;VOICE" matches "TEL;TYPE=FAX,VOICE"
+ * or "TEL;FAX;TYPE=VOICE" or "TEL;TYPE=FAX;TYPE=VOICE" and of course
+ * "TEL;FAX;VOICE".
+ *
  * When all tokens are matched we found matching line.
  */
-gboolean ReadVCALText(char *Buffer, const char *Start, unsigned char *Value, const gboolean UTF8)
+gboolean ReadVCALText(char *Buffer, const char *Start, unsigned char *Value, const gboolean UTF8, GSM_EntryLocation *location)
 {
 	char *line = NULL;
 	char **tokens = NULL;
@@ -520,13 +525,17 @@ gboolean ReadVCALText(char *Buffer, const char *Start, unsigned char *Value, con
 	pos += len;
 	/* No need to check this token anymore */
 	tokens[0][0] = 0;
+	/* Initialize location */
+	if (location != NULL) {
+		*location = PBK_Location_Unknown;
+	}
 
 	/* Check remaining tokens */
 	while (*pos != ':') {
 		if (*pos == ';') {
 			pos++;
 		} else {
-			dbgprintf(NULL, "Could not parse!\n");
+			dbgprintf(NULL, "Could not parse! (stopped at string: %s)\n", pos);
 			goto fail;
 		}
 		found = FALSE;
@@ -593,14 +602,83 @@ gboolean ReadVCALText(char *Buffer, const char *Start, unsigned char *Value, con
 				}
 				pos = end;
 				found = TRUE;
-			} else if (strncasecmp(pos, "TYPE=PREF", 9) == 0) {
-				/* We ignore pref token */
-				pos += 9;
-				found = TRUE;
+			} else if (strncasecmp(pos, "TYPE=", 5) == 0) {
+				/* We ignore TYPE= prefix */
+				pos += 5;
+
+				/* Now process types, which should be comma separated */
+				while (*pos != ':' && *pos != ';') {
+					found = FALSE;
+
+					/* Go through tokens to match */
+					for (token = 0; token < numtokens; token++) {
+						len = strlen(tokens[token]);
+						/* Skip already matched tokens */
+						if (len == 0) {
+							continue;
+						}
+						if (strncasecmp(pos, tokens[token], len) == 0) {
+							dbgprintf(NULL, "Found %s\n", tokens[token]);
+							/* Advance position */
+							pos += len;
+							/* We need to check one token less */
+							tokens[token][0] = 0;
+							found = TRUE;
+							break;
+						}
+					}
+
+					if (!found) {
+						if (strncasecmp(pos, "PREF", 4) == 0) {
+							/* We ignore pref token */
+							pos += 4;
+							found = TRUE;
+						} else if (strncasecmp(pos, "WORK", 4) == 0) {
+							/* We ignore work token */
+							pos += 4;
+							found = TRUE;
+							if (location != NULL) {
+								*location = PBK_Location_Work;
+							}
+						} else if (strncasecmp(pos, "HOME", 4) == 0) {
+							/* We ignore home token */
+							pos += 4;
+							found = TRUE;
+							if (location != NULL) {
+								*location = PBK_Location_Home;
+							}
+						} else {
+							dbgprintf(NULL, "%s not found! (%s)\n", Start, pos);
+							goto fail;
+						}
+					}
+
+					if (*pos == ';' || *pos == ':') {
+						dbgprintf(NULL, "End of TYPE= string\n");
+						break;
+					} else if (*pos == ',') {
+						/* Advance past separator */
+						pos++;
+					} else {
+						dbgprintf(NULL, "Could not parse TYPE=! (stopped at string: %s)\n", pos);
+						goto fail;
+					}
+
+				}
 			} else if (strncasecmp(pos, "PREF", 4) == 0) {
 				/* We ignore pref token */
 				pos += 4;
 				found = TRUE;
+			} else if (location && strncasecmp(pos, "WORK", 4) == 0) {
+				/* We ignore pref token */
+				pos += 4;
+				found = TRUE;
+				*location = PBK_Location_Work;
+			} else if (location && strncasecmp(pos, "HOME", 4) == 0) {
+				/* We ignore pref token */
+				pos += 4;
+				found = TRUE;
+				*location = PBK_Location_Home;
 			}
 			if (!found) {
 				dbgprintf(NULL, "%s not found!\n", Start);
