@@ -1,5 +1,5 @@
 /* Copyright (c) 2002-2004 by Marcin Wiacek and Joergen Thomsen */
-/* Copyright (c) 2009 - 2011 Michal Cihar <michal@cihar.com> */
+/* Copyright (c) 2009 - 2012 Michal Cihar <michal@cihar.com> */
 
 #include <string.h>
 #include <signal.h>
@@ -264,13 +264,13 @@ void SMSD_Log(SMSD_DebugLevel level, GSM_SMSDConfig *Config, const char *format,
 		case SMSD_LOG_SYSLOG:
 #ifdef HAVE_SYSLOG
 			switch (level) {
-				case -1:
+				case DEBUG_ERROR:
 					priority = LOG_ERR;
 					break;
-				case 0:
+				case DEBUG_INFO:
 					priority = LOG_NOTICE;
 					break;
-				case 1:
+				case DEBUG_NOTICE:
 					priority = LOG_INFO;
 					break;
 				default:
@@ -1912,12 +1912,14 @@ GSM_Error SMSD_MainLoop(GSM_SMSDConfig *Config, gboolean exit_on_failure, int ma
 	 		lastreceive = time(NULL);
 
 			/* Do we need to check security? */
-			if (Config->checksecurity && !SMSD_CheckSecurity(Config)) {
-				errors++;
-				initerrors++;
-				continue;
-			} else {
-				errors = 0;
+			if (Config->checksecurity) {
+				if (!SMSD_CheckSecurity(Config)) {
+					errors++;
+					initerrors++;
+					continue;
+				} else {
+					errors = 0;
+				}
 			}
 
 			initerrors = 0;
