@@ -28,6 +28,9 @@
 #define HAVE_UID
 #include "uid.h"
 #endif
+#ifdef HAVE_WINDOWS_EVENT_LOG
+#include "log-event.h"
+#endif
 
 #if !defined(WIN32)
 #define HAVE_DEFAULT_CONFIG
@@ -36,6 +39,7 @@ const char default_config[] = "/etc/gammu-smsdrc";
 
 GSM_SMSDConfig *config;
 volatile gboolean reconfigure = FALSE;
+volatile gboolean standby = FALSE;
 
 void smsd_interrupt(int signum)
 {
@@ -49,6 +53,18 @@ void smsd_reconfigure(int signum)
 	SMSD_Shutdown(config);
 }
 
+void smsd_standby(int signum)
+{
+	standby = TRUE;
+	reconfigure = TRUE;
+	SMSD_Shutdown(config);
+}
+
+void smsd_resume(int signum)
+{
+	standby = FALSE;
+}
+
 NORETURN void version(void)
 {
 	printf("Gammu-smsd version %s\n", GAMMU_VERSION);
@@ -154,6 +170,10 @@ void help(void)
 #endif
 	print_option("l", "use-log", "use logging configuration from config file (default)");
 	print_option("L", "no-use-log", "do not use logging configuration from config file");
+#ifdef HAVE_WINDOWS_EVENT_LOG
+	print_option("e", "install-event-log", "installs Windows EventLog description to registry");
+	print_option("E", "uninstall-event-log", "uninstalls Windows EventLog description to registry");
+#endif
 }
 
 NORETURN void wrong_params(void)
@@ -185,13 +205,15 @@ void process_commandline(int argc, char **argv, SMSD_Parameters * params)
 		{"max-failures", 1, 0, 'f'},
 		{"use-log", 0, 0, 'l'},
 		{"no-use-log", 0, 0, 'L'},
+		{"install-event-log", 0, 0, 'e'},
+		{"uninstall-event-log", 0, 0, 'E'},
 		{0, 0, 0, 0}
 	};
 	int option_index;
 
-	while ((opt = getopt_long(argc, argv, "hvdc:p:iusSkU:G:n:X:f:lL", long_options, &option_index)) != -1) {
+	while ((opt = getopt_long(argc, argv, "hvdc:p:iusSkU:G:n:X:f:lLeE", long_options, &option_index)) != -1) {
 #elif defined(HAVE_GETOPT)
-	while ((opt = getopt(argc, argv, "hvdc:p:iusSkU:G:n:X:f:lL")) != -1) {
+	while ((opt = getopt(argc, argv, "hvdc:p:iusSkU:G:n:X:f:lLeE")) != -1) {
 #else
 	/* Poor mans getopt replacement */
 	int i;
@@ -240,6 +262,14 @@ void process_commandline(int argc, char **argv, SMSD_Parameters * params)
 				params->daemonize = TRUE;
 				break;
 #endif
+#ifdef HAVE_WINDOWS_EVENT_LOG
+			case 'e':
+				params->install_evlog = TRUE;
+				break;
+			case 'E':
+				params->uninstall_evlog = TRUE;
+				break;
+#endif
 #ifdef HAVE_WINDOWS_SERVICE
 			case 'i':
 				params->install_service = TRUE;
@@ -299,6 +329,10 @@ void configure_daemon(SMSD_Parameters * params)
 #ifdef HAVE_ALARM
 	signal(SIGALRM, smsd_interrupt);
 #endif
+#if defined(HAVE_SIGUSR1) && defined(HAVE_SIGUSR2)
+	signal(SIGUSR1, smsd_standby);
+	signal(SIGUSR2, smsd_resume);
+#endif
 
 #ifdef HAVE_DAEMON
 	/* Daemonize has to be before writing PID as it changes it */
@@ -360,6 +394,8 @@ int main(int argc, char **argv)
 		FALSE,
 		FALSE,
 		FALSE,
+		FALSE,
+		FALSE,
 		TRUE,
 		0
 	};
@@ -395,6 +431,26 @@ int main(int argc, char **argv)
 	}
 #endif
 
+#ifdef HAVE_WINDOWS_EVENT_LOG
+	if (params.install_evlog) {
+		if (eventlog_register()) {
+			printf("Installed event log description\n");
+			exit(0);
+		} else {
+			printf("Failed to install event log description!\n");
+			exit(1);
+		}
+	}
+	if (params.uninstall_evlog) {
+		if (eventlog_deregister()) {
+			printf("Uninstalled event log description\n");
+			exit(0);
+		} else {
+			printf("Failed to uninstall event log description!\n");
+			exit(1);
+		}
+	}
+#endif
 	if (params.config_file == NULL) {
 #ifdef HAVE_DEFAULT_CONFIG
 		params.config_file = default_config;
@@ -442,6 +498,7 @@ read_config:
 		configure_daemon(&params);
 
 	reconfigure = FALSE;
+	standby = FALSE;
 	error = SMSD_MainLoop(config, FALSE, params.max_failures);
 	if (error != ERR_NONE) {
 		printf("Failed to run SMSD: %s\n", GSM_ErrorString(error));
@@ -451,6 +508,14 @@ read_config:
 
 	SMSD_FreeConfig(config);
 
+	/*
+	 * Wait while we should be suspended.
+	 * Later we fall back to reconfigure bellow.
+	 */
+	while (standby) {
+		sleep(1);
+	}
+
 	if (reconfigure) {
 		goto read_config;
 	}
